# core.signal

## audio_extensions

::: fastaudio.core.signal.audio_extensions
> List of extensions suitable for audio files


## get_audio_files

::: fastaudio.core.signal.get_audio_files
    :docstring:
    :members:

## AudioGetter

::: fastaudio.core.signal.AudioGetter
    :docstring:
    :members:

## tar_extract_at_filename

::: fastaudio.core.signal.tar_extract_at_filename
    :docstring:
    :members:

## AudioTensor

::: fastaudio.core.signal.AudioTensor
    :docstring:
    :members: create nsamples nchannels duration hear show

## OpenAudio

::: fastaudio.core.signal.OpenAudio
    :docstring:
